@@ -2,4 +2,4 @@
 Defines interfaces exposed to library user
 """
 from membank.interface import LoadMemory
-from membank.interface import GeneralMemoryError
+from membank.errors import *
